@@ -4,6 +4,9 @@ our @ISA = qw(App::TimeClock::PrinterInterface);
 
 use POSIX qw(strftime);
 
+use utf8;
+binmode STDOUT, ':utf8';
+
 our $hrline =  '+' . ('-' x 62) . '+' . ('-' x 7) . '+';
 
 =head1 NAME
@@ -87,7 +90,7 @@ sub print_footer {
     my ($self, $work_year_to_date, $day_count) = (@_);
     printf "TOTAL = %.2f hours\n", $work_year_to_date;
     printf "PERIOD = %d days\n", $day_count;
-    printf "AVERAGE = %.2f hours/day\n", $work_year_to_date / $day_count;
+    printf "AVERAGE = %.2f hours/day\n", $day_count > 0 ? $work_year_to_date / $day_count : 0;
 };
 1;
 
